---
title: "Choosing a Starter Ship in Star Citizen 4.0"
date: 2025-01-01
draft: true
versioned: star-citizen-starter-guide
tags:
  - video games
  - game guide
  - star citizen
---
Welcome to my guide for choosing a starter ship in Star Citizen 4.0!

So you've watched some Youtube videos or Twitch streams and decided you want to play Star Citizen. Your interest piqued, you go to <https://robertsspaceindustries.com> and click the "Pledge Store" link. Then, being a naturally thorough and curious sort of person, you click the link that says "View All Game Packages."

Now you are presented with a full 15 options, ranging in price from $45 to... $1100? What is going on here? A new player has no way to actually judge these relative to each other. You can play during the few "free fly" events scattered throughout the year, but the game can be overwhelming at first, and trying to test drive over a dozen ships while the servers are overloaded is a stressful idea even for many veteran players.

If this is you, and you've got decision paralysis, maybe I can help. This is a somewhat opinionated guide for choosing which ship to start out with in Star Citizen. Rather than a ranked list, however, this time around I'm going to "sell" each ship, with an emphasis on who each ship is a good choice for.

<!--more-->

# Caveat Emptor

Before deciding on a starter ship, you should step back and evaluate whether you actually want to play this game. Because, fair warning: when you "pledge" a "game package", you are not buying a game in the traditional sense. You aren't even buying an Early Access game. You are paying for the privilege of being a QA tester. Because despite the massive budget, despite the seemingly endless time this game has been in dev, the fact is that this is still *far* from a complete game.

Granted, Star Citizen creates some absolutely magical moments that you can find nowhere else, *especially* when you play it with friends. But it requires a uniquely high frustration tolerance. This can't be emphasized enough: this game is *buggy*, it is *unoptimized*, and it will test your patience every single time you log in. Sometimes a patch is sufficiently broken that the game is nearly unplayable for months at a time. Even in the best of times, the gameplay loops are often buggy, shallow, or half-implemented. Missions frequently just break, impacting your reputation with the faction that gave you the mission. This is a partially built sandbox, and you have to find your own fun. It is poorly optimized and requires far more expensive hardware than most other games, and even with top of the line hardware it is not always going to run smoothly. The project as a whole can credibly be accused of massive scope creep and dubious marketing practices.

That said, I play this game regularly and I have a blast. Your mileage may vary drastically. And it comes with a generous refund policy if it isn't what you want it to be, so you can try it out with minimal risk. You can also wait for the "Free Fly" events that happen periodically, where you can create an account and play for several days without spending any money.

## System Requirements

The system requirements listed on the Star Citizen website are... optimistic. They'll *run* the game, but it won't be a satisfying experience for most people. I *strongly* recommend the following as the baseline system requirements for a decent experience, in priority order:

* An NVMe SSD
* 32 GB RAM
* The best CPU you can afford, with a focus on L3 cache. (the AMD X3D series is ideal for Star Citizen)
* A GPU with at least 12 GB of VRAM.

If you aren't familiar with PC hardware, a detailed explanation is beyond the scope of this guide. However, something like [this guide](https://www.tomshardware.com/best-picks/best-pc-builds-gaming) might be a decent place to start. (at the time of writing, their $800 build could run Star Citizen *playably* at 1080p, and their $1000 build could run it comfortably)

## The Elephant in the Room

As you can see from the "Pledge Store", Cloud Imperium Games charges different prices for different starter ships, and you tend to get more capability for more money. Plenty of digital ink has been spilled discussing the ethics of their business model, and I certainly don't love it. You can think of these as various levels of "premium edition" bundles, though if it feels too pay-to-win for your tastes, I certainly won't argue.

That said, the game is mostly PvE and/or coop, so the "pay to win" aspect doesn't hit that hard. And there are good starter ships in the "standard AAA game" price range.


# What makes a ship a starter ship?

I'm defining a "starter" as a fully solo multi-role ship suitable for "getting your feet wet" in the Star Citizen universe. A starter should have all of the following features. Note that this excludes a number of ships listed as starter packages in the pledge store, because I simply don't think they make good starter ships.

* It must be listed as a ["game package" option in the pledge store](https://robertsspaceindustries.com/store/pledge/browse/game-packages/?sort=weight&direction=desc). You can use any ship as a starter by buying a starter pack and upgrading, but these are chosen as the entry points for a reason, and for a new player, figuring out what a "CCU" is and how to do it is unnecessary complexity.
* Small in size. Larger ships take more finesse to fly and land, and take longer to respawn after being destroyed. So, a good starter should be small.
* At least 2 SCU ("standard container units", a cargo container sizing standard in Star Citizen) of cargo space. Even if you don't want to haul any cargo, the cargo space has a variety of uses, from hauling gear in Stor-All containers to carrying extra ship components or weapons for on the fly repairs.
* A decent amount of quantum fuel, so it can get around the system without having to worry about pit stops.
* It should not be a specialist variant - those tend to sacrifice versatility for "cool" features. These are great ships to acquire later, after you know what gameplay you like best.
* Fully solo - all of the ship's flight and combat systems should be available to the pilot.

In addition to these hard requirements, there are several desirable features in a starter ship. These reviews will flag any that are *missing* from each ship. Features that aren't implemented yet but will be desirable once they are will be listed with "(future consideration)" next to them. They are:

* A bed - for staying "out in the black" longer. Using your ship's bed to log out allows you to log back in in the exact place you left off. Normally you have to dock and stow your ship before logging out or else you'll have to "Claim" (as in "file an insurance claim") the ship later, which requires waiting a short time and also strips the ship of any cargo it was carrying. 
* Weapon racks and suit lockers - These give you quick access to changing your loadout before stepping outside your ship for some FPS action. (suit lockers are not yet implemented) (TK: verify)
* Hygiene facilities - An upcoming feature will require occasional showers to avoid angering NPCs.
* A walkable interior - Being able to walk around inside your ship is immersive, fun, and gives you a space to decorate or to store additional small items.

In addition, these are "premium" starter features worth considering depending on what activities you want to do:

* Enough room to stow a ground vehicle. This adds some versatility - for instance, if your starter can fit a Roc, you can try out mining.
* Additional seats - starter ships are solo by design, but this enables you to perform rescue missions. (a bed also counts as an additional seat for these purposes)
* A tractor beam - great for scavenging or for moving ground vehicles around when they get stuck.
* Quick cockpit access - see "other factors to consider" below.

## What can you do with your starter ship?

With a modest array of weapons, you can:

* Do entry-level ship-based bounty hunting.
* Protect yourself when hauling cargo.

With a few SCU (Standard Cargo Units) of cargo space, you can:

* Try out cargo hauling.
* Do delivery missions.[^1]
* Scavenge cargo from wrecks. (you can even pick your bounty targets clean after destroying them)

With a small footprint and a decent quantum fuel supply, you can:

* Get around to all of the on-foot content easily.

There are some specialized forms of gameplay that your starter ship won't be capable of. Luckily, all of them require ships or tools that you can rent or buy in game, and your starter ship is the key to, well, getting started.

## Other Factors to Consider

* The age of a ship (as in, when it was introduced to the game) can have a strong influence on how much fun it will be to fly. Ships that were introduced a long time ago will not have as much polish as more recent ships. The Aurora is really showing its age compared to the Cutter, for instance. Things that older ships might not have include weapon racks and suit lockers, bathroom facilities, buttons for open/closing doors and controlling interior lights, and "physicalized" components that you can remove and replace by hand. (for example, on a newer ship you can pull the shield generator out and replace it with one you found while scavenging) All ships will eventually receive a "gold standard" polish pass, but in the meantime it is a factor to consider. (TK: check physicalized component status in 3.24)

* "Time to cockpit" is a metric of how long it takes to get into the pilot's seat once you're at the ship. Some ships have much faster access to and from the cockpit, making them great if you want to do a lot of FPS / on-foot gameplay.

* If you are absolutely certain you want to do exactly one type of gameplay, ignore this advice and get a ship tailored to that gameplay. If all you want to do is dogfighting all day, get a fighter, but maybe pay attention to its quantum range. If your dream is to be a Space Medic, get a Pisces Rescue or spring for a Cutlass Red. (but you should know you will struggle to make credits doing that sort of gameplay right now. On the other hand, the Pisces Rescue is a solid runabout if you are exclusively interested in FPS gameplay) If you are sure the only thing you want is to mine rocks, get a Prospector, but know that mining breaks every other patch or so.

* Some features described on CIG's website may not be in the game yet, and there may be features coming soon that change the balance of which ships are best. The nature of playing a game still in alpha is that it's something of a moving target. For example, the upcoming "hygiene" requirements will reward having shower facilities on board your ship.[^2] Given the volatility of development, I'll include some predictable future considerations where relevant. However, changes with large scope and direct ship-based implications, like engineering, ship armor, and the Maelstrom damage model will require new versions of this guide. In other words, these rankings are subject to change!


# The Starter Ships, Reviewed

Ok, on to the good stuff. Here are all the ships I think qualify as starters.[^3] Since the last installment of this guide, the game has added Engineering and TK, so each entry has some information detailing those features.

To avoid any feeling of bias towards one ship or another, they are listed in alphabetical order. (some bias may slip in, but I have strived to give each ship a fair review) Prices listed are the standard prices; discounts are occasionally available for select starter packages.

---

## 100i (Origin Jumpworks)

{{< imgproc "images/100i.jpg" "400x" "right" "The Origin Jumpworks 100i in a hangar." />}}

### Price
* $65

### Loadout
* 2x size 3 guns
* 1x size 2 missile rack
* 2 SCU cargo grid

### Missing Features
* Hygiene facilities (future consideration)
* Weapon rack
* Suit locker (future consideration)

The 100i is sleek and white. Origin is the BMW of Star Citizen, making luxury ships at a variety of price points. If you like the aesthetic, this is a classy little ship for getting around in.

However, the luxury comes with a cost; Origin can sometimes prioritize form over function. In the case of the 100i, that means its 2 SCU of cargo space can only be accessed through the main door, which can be a bit tricky.

That said, it has a good silhouette for combat. It isn't super well-armed, but it can hold its own, and presents a minimal cross-section when attempting to escape from hostile forces.

If you want to feel like the Space Elite, touching down for a soirée at New Babbage in style, the 100i is your perfect starter ship.

---

## Aurora MR (RSI)

{{< imgproc "images/aurora.jpg" "400x" "right" "The RSI Aurora MR in a hangar." />}}

### Price
* $45

### Loadout
* 2x size 1 guns
* 1x size 2 missile rack
* 3 SCU cargo grid

### Missing Features
* Weapon rack
* Physicalized components (TK)
* Hygiene facilities (future consideration)
* Suit locker (future consideration)

The Aurora is a cute little ship, with round doors that have a very distinctive animation and a profile reminiscent of a dragonfly with its wings furled. It's definitely the Hyundai Elentra of the Elite universe; nothing fancy in terms of amenities or capabilities, just a basic, everyday spaceship. The second starter added to the game, the Aurora has a bed and a small interior. The identically priced Mustang is a bit more capable in both combat and storage, but the Aurora adds the small luxury of a bed, making it possible to log out more "cleanly" without first going back to civilization.

The animation for getting into the pilot's seat adds an unnecessary amount of time-to-cockpit for such a small ship, and the interior feels like it's only walkable on a technicality. The underslung cargo rack is somewhat difficult to load, since containers must be slid in from the front. It's probably a little bit less cumbersome to load than the Mustang's "cargo box", but it's still one of the more fiddly cargo grids in the game. It's considerably easier to load when floating in space, so that awkwardness will be less when looting your kills after some space combat.

You should buy this ship if you want to feel like an "average citizen" just getting their start in the 'verse.

---

## Avenger Titan (Aegis Dynamics)

{{< imgproc "images/avenger.jpg" "400x" "right" "The Aegis Dynamics Avenger Titan in a hangar." />}}

### Price
* $75

### Loadout
* 1x size 4 gun
* 2x size 3 guns
* 2x size 3 missile racks
* 8 SCU cargo grid

### Premium Features
* Direct cockpit access
* Interior cargo space can fit the Pulse hoverbike

### Missing Features
* Weapon rack
* Suit locker (future consideration)
* Hygiene facilities (future consideration)

{{< imgproc "images/avenger_cockpit.jpg" "300x" "left" "The Avenger's quick-access cockpit configuration." >}}Easy cockpit access for the pilot on the go.{{</imgproc>}}

When you ask a lot of people what starter to get, they'll say "get the Avenger Titan, you can't go wrong with it." And it's hard to argue. The Avenger Titan from Aegis Dynamics is an all-around great starter, and if price isn't a huge concern, this is pretty much your de facto pick. Unless you really like the style of another ship or want to pay extra for the Nomad, the Titan is an unbeatable choice.

{{< imgproc "images/avenger_bay.jpg" "300x" "right" "The Avenger's cargo bay.">}}A cozy cargo bay{{</imgproc>}}

For its premium price tag, the Aegis Avenger Titan gives you the biggest guns on the list, the second-biggest missile loadout bigger missiles, and a cargo hold large enough to start to feel like a proper hauler. It is also quite nimble and small enough to land anywhere your journey takes you. It doesn't have all the amenities of other ships, but it does have the most crucial one: a bed.

{{< imgproc "images/avenger_hab.jpg" "300x" "left" "The Avenger's habitation area." >}}An even cozier habitation section.{{</imgproc>}}

You should buy this ship if you want a solid foundation for getting into ship-based gameplay, especially combat and entry-level cargo hauling. It offers a great balance between price and capabilities.

---

## C8X Pisces Expedition (Anvil Aerospace)

{{< imgproc "images/pisces.jpg" "400x" "right" "The Anvil Aerospace C8X Pisces Expedition in a hangar." />}}

### Price
* $60

### Loadout
* 4x size 1 guns
* 2x size 1 missile racks
* 4 SCU cargo grid

### Premium Features
* 2x jumpseats for transporting passengers
* Interior cargo space can fit the Pulse hoverbike

### Missing Features
* Bed
* Weapon rack
* Suit locker (future consideration)
* Hygiene facilities (future consideration)

Piloting the Anvil Aerospace Pisces feels like being a shuttle pilot in Star Trek. It is a tiny little ship with a classic profile. It includes 2 passenger seats, making it great for carrying a small force to a ground mission or for rescue operations. The Pisces also has decent firepower for its price, so if ship-based combat is something you're interested in, this is one of the less expensive choices that starts to feel viable. The flat silhouette presents a smaller target for your opponents. A nicely balanced choice overall, and fairly popular in the Star Citizen community.

It's hard to emphasize how comparatively *small* the Pisces is. It feels more like a snub ship than anything; indeed, the Carrack comes with a slightly different model as a built-in shuttlecraft. Combined with the quick exit and jumpseats, this makes the Pisces an excellent choice for "hot drop" operations, where you might want to get in fast, get some boots on the ground, and get back out in a hurry.

You should buy this ship if you have a couple friends to play with and want to be the pilot who can get them to the action in a hurry. If you want more advanced facilities like weapon racks, beds, or living space, though, look elsewhere.

---

## Cutter (Drake Interplanetary)

{{< imgproc "images/cutter.jpg" "400x" "right" "The Drake Interplanetary Cutter in a hangar." />}}

### Price
* $60

### Loadout
* 2x size 2 guns
* 2x size 2 missile racks
* 4 SCU cargo grid

### Premium Features
* Interior cargo space can fit the Pulse hoverbike and PTV ground buggy

The Drake Interplanetary Cutter is a direct price competitor to the Pisces. Its weapons have less sustained damage but more missiles, and it has a much boxier silhouette than the Pisces as well. Combined with the slightly more spacious interior and living amenities, this is a ship which is less focused on combat scenarios and more focused on being a general runabout. It doesn't fly as well in atmospheres as the Pisces, owing to its complete lack of aerodynamics. But it *does* have VTOL-capable engines, and which makes it a solid "getaway car" because it can go straight up in a hurry. Also it's pretty cool to watch the engines rotate into place.

It also has all of the desirable quality of life features for current and future gameplay, which makes it a great choice for a ship to "live out of". If you want to roleplay a nomad, camping out on Microtech or sleeping among the stars, this is the space van of your dreams. If you want even more interior amenities, the Cutter Scout shrinks the cargo hold for slightly expanded crew quarters.

This ship has been described as being particularly well-armored, so once ship armor is implemented it may be an ideal choice for players who would rather retreat from combat situations than engage.

You should buy this ship if you want to live that space van life, carrying everything you need with you and touring the galaxy on your own terms. If you're interested in jumping right into spaceship-based combat, though, this might not be the best choice.

---

## Mustang Alpha (Consolidated Outland)

{{< imgproc "images/mustang.jpg" "400x" "right" "The Consolidated Outland Mustang Alpha in a hangar." />}}

### Price
* $45

### Loadout
* 2x size 1 guns
* 2x size 2 guns
* 4 SCU cargo grid

### Premium Features
* Direct cockpit access

### Missing Features
* Walkable interior
* Physicalized components (TK)
* Bed
* Weapon rack
* Suit locker (future consideration)
* Hygiene facilities (future consideration)

If the Aurora is the Hyundai Elantra of the Star Citizen universe, then the Mustang is the Honda Civic. The original starter ship, the Mustang Alpha from Consolidated Outland is still a surprisingly strong contender, depending on what you want to do in the game. It has a classic "space fighter" aesthetic with wings that fold up in landing mode. The very first ship designed for the game, it is the only ship in this list without a walkable interior - it *only* has direct cockpit access, so it definitely feels more like a fighter plane than something a long-haul spacefarer would want to live in. It is fast and nimble and has great sustained damage output for its price, if dogfighting is something that appeals to you. You won't see higher sustained damage potential until you get to the premium price range. ($75 or more)

It does have a cargo hold in the form of a deployable "cargo box". Loading cargo containers it requires some finesse and wiggling, making it a bit trickier to load than other comparable ships.

You should buy this ship if you want to feel like a space combat pilot just starting out; a mercenary or a bounty hunter, or perhaps an escort pilot. It's also a good runabout if you really value getting into and out of your ship in a hurry.

---

## Nomad (Consolidated Outland)

{{< imgproc "images/nomad.jpg" "400x" "right" "The Consolidated Outland Nomad in a hangar." />}}

### Price
* $95

### Loadout
* 3x size 3 guns
* 2x size 4 missile racks
* 24 SCU cargo grid

### Premium Features
* Unique "pickup bed" cargo area can fit the Pulse hoverbike, PTV, STV, and Cyclone ground buggies, Roc mining vehicle, and the Fury snub fighter (if you're very careful)
* Tractor beam

By far the most versatile starter, the Consolidated Outland Nomad can do it all and has a lot of premium features to match its premium price. Often called the "space pickup" because its cargo grid is on a lowerable platform on the exterior of the ship. This means the cargo isn't fully enclosed, and is not accessible from inside the ship's living area. This also means your cargo (or ground vehicle) may be damaged or dislodged if you come under attack. However, at 24 SCU of cargo it towers above any other option on this list in terms of cargo storage. It is also the only ship on the list with a ship-mounted tractor beam, which makes it an *excellent* choice for getting into cargo hauling.

{{< imgproc "images/nomad_interior.jpg" "300x" "left" "The Nomad's angular interior design.">}}Strange, sharp angles define the interior spaces.{{</imgproc>}}

In terms of combat, the most obvious points of comparison here are the Avenger Titan and the Syulen. With 3 size 3 hardpoints, it matches the Syulen for firepower and has a better head-on silhouette. It sits between the Avenger and Syulen on missile loadout. Perhaps most significatly, it carries 3 shield generators, so its shields can take quite a beating.

Another thing to note about the Nomad is that it has a unique aesthetic. It uses hover tech on its entryway and landing gear and has a very angular, almost alien interior. (obviously less alien than the Syulen, but still) A lot of people think the piloting console looks a little "cheap" because it has oddly flat displays and "Star Trek" style virtual buttons on glass panes. I think it is a distinctive and interesting look, but your mileage may vary.

{{< imgproc "images/nomad_cockpit.jpg" "300x" "right" "The Nomad's distinctive control console." >}}A distinctive approach to console buttons.{{</imgproc>}}

You should buy this ship if you want to be a cargo hauler, shipping goods around the 'verse chasing profits. It's also a great choice if you aren't at all worried about the buy-in cost of the game and just want the most capable all-around starter. (although in that case you may also consider upgrading to a medium-sized ship as well)

One final caveat about the Nomad: its stock configuration has some power supply issues that can result in overheating. You should plan to upgrade the power plant immediately.


---

## Syulen (Gatac)

{{< imgproc "images/syulen_landed.jpg" "400x" "right" "The Gatac Syulen landed in a hangar." />}}

### Price
* $85

### Loadout
* 3x size 3 guns
* 3x size 4 missile racks
* 6 SCU cargo grid (but can only carry 1 SCU boxes)

### Premium Features
* It's cool as hell

The Gatac Syulen is the newest starter, introduced at IAE 2953. It is beautiful, elegant, imposing. It has personality. It sings at full throttle. It has solid firepower; being tied for second with the Nomad on sustained firepower. It is extremely maneuverable. And the interior is littered with writing in the Xi'an language, which is a huge bonus if you're into the constructed languages in Star Citizen lore.

{{< imgproc "images/syulen_flight.jpg" "400x" "left" "The Gatac Syulen in flight configuration." >}}Beautiful radial symmetry.{{</imgproc>}}

That said, it has a very long time-to-cockpit, its cargo grid is external and not flat, so it gets no vehicle storage and can't fit cargo containers larger than 1 SCU. The vertical takeoff and landing profile can be tricky, especially in horizontal hangars, making takeoff and landing quite a challenge. And it has a hefty "alien tax", being a fair bit more expensive than the loadout warrants. It also has a huge silhoutte for a small ship, making it an easy target in combat.

It does boast the best missile loadout of all the ships on this list, but the Titan is cheaper and has better guns, and the Nomad is about the same price and is more practical in every way, plus comes with *4 times* the cargo capacity.

You should buy this ship if the allure of alien languages and unusual, elegant design calls to you above any practical considerations.


&nbsp; 

&nbsp; 

---

# I'm Tired of Flying a Starter Ship, What Should I Do Now?

You have 2 main routes in this case: get a specialized ship and do some specialized gameplay, or else upgrade to a medium-sized "daily driver" soloable ship, like the Freelancer, C1 Spirit, or Cutlass Black. If you like the feeling and challenge of flying larger/more cumbersome ships, you can consider something like the Corsair, Constellation, MSR, or the C2 Hercules. Whether you earn credits in-game to purchase these ships[^4] or buy them with your real money on the [pledge store](https://robertsspaceindustries.com/pledge) is a personal decision; I'm not a huge fan of CIG's business model, but if you have more expendable income than free time and want to get right to the ships you think sound fun, I feel like that's a perfectly reasonable decision.

[^1]: "Box delivery" missions are often bugged, so may or may not actually be a good activity to do.
[^2]: Love it or hate it, hygiene gameplay is coming for us all.
[^3]: I will post new versions of this guide as new starters are added to the game as well. If you're reading an outdated guide, there should be a big yellow notice at the top of the page telling you so.
[^4]: Note that, while the game is still in Alpha, ships purchased in-game will be lost every time the devs do a database wipe. This happens about once a year, but there are no guarantees.
