---
title: "Choosing a Starter Ship in Star Citizen 3.22"
date: 2023-11-27
versioned: star-citizen-starter-guide
tags:
  - video games
  - game guide
  - star citizen
---
So you've watched some Youtube videos or Twitch streams and decided you want to play Star Citizen. Your interest piqued, you go to <https://robertsspaceindustries.com> and click the "Pledge Store" link, and then, being a naturally thorough and curious sort of person, you click the link that says "View All Game Packages."

Now you are presented with a full 15 options, ranging in price from $45 to... $1100? What is going on here? A new player has no way to actually judge these relative to each other. You can play during the few "free fly" events scattered throughout the year, but the game can be overwhelming at first, and trying to test drive over a dozen ships while the servers are overloaded is a stressful idea even for many veteran players.

If this is you, and you've got decision paralysis, maybe I can help. This is an opinionated guide to choosing which ship to start out with in Star Citizen.

<!--more-->

# What makes a ship a starter ship?

I'm defining a "starter" as a fully solo multi-role ship suitable for "getting your feet wet" in the Star Citizen universe. A starter should have all of the following features. Note that this excludes a number of ships listed as starter packages in the pledge store, because I simply don't think they make good starter ships.

* It must be listed as a ["game package" option in the pledge store](https://robertsspaceindustries.com/store/pledge/browse/game-packages/?sort=weight&direction=desc). You can use any ship as a starter by buying a starter pack and upgrading, but these are chosen as the entry points for a reason.
* Small in size. Larger ships take more finesse to fly and particularly to land, so a good starter should be small. This also means a smaller footprint (for landing) and silhouette. (for avoiding damage in combat)
* At least 2 SCU of cargo space.
* A decent amount of quantum fuel, so it can get around the system without having to worry about pit stops.
* It should not be a specialist variant - those tend to sacrifice versatility for "cool" features, and are great ships to buy later, after you know what gameplay you like best.
* Fully solo - all of the ship's systems should be available to the pilot.

In addition, these are "premium" starter features worth considering depending on what activities you want to do:

* A bed / living amenities - for staying "out in the black" longer. Using your ship's bed to log out allows you to log back in in the exact place you left off. Normally you have to dock and stow your ship before logging out or else you'll have to "Claim" (as in "file an insurance claim") the ship later, which requires waiting a short time and also strips the ship of any cargo it was carrying. 
* Enough room to stow a ground vehicle. This adds some versatility - for instance, if your starter can fit a Roc, you can try out mining.
* Additional seats - starter ships are solo by design, but this enables you to perform rescue missions. (a bed also counts as an additional seat)
* A tractor beam - great for scavenging or for moving ground vehicles around when they get stuck.
* Weapon racks / suit lockers - eventually these will be useful, but the gameplay for them isn't fully implemented. Right now they're just "nice to have".
* Quick cockpit access - see "other factors to consider" below.

# What can you do with your starter ship?

With a modest array of weapons, you can:

* Do ship-based bounty hunting.
* Protect yourself when hauling cargo.

With a few SCU (Standard Cargo Units) of cargo space, you can:

* Try out cargo hauling.
* Do delivery missions.[^1]
* Scavenge cargo from wrecks. (you can even pick your bounty targets clean after destroying them)

With a small footprint and a decent quantum fuel supply, you can:

* Get around to all of the on-foot content without too much worry.

There are some specialized forms of gameplay that your starter ship won't be capable of. Luckily, almost all of them require ships or tools that you can rent or buy in game, and your starter ship is the key to getting started.

# Other Factors to Consider

* The age of a ship can have a strong influence on how much fun it will be to fly. Ships that were introduced a long time ago will not have as much polish as more recent ships. The Aurora is really showing its age compared to the Cutter, for instance. Things that older ships might not have include weapon racks and suit lockers, bathroom facilities, buttons for open/closing doors and controlling interior lights, and "physicalized" components that you can remove and replace by hand. (for example, on a newer ship you can pull the shield generator out and replace it with one you found while scavenging) All ships will eventually receive a "gold standard" polish pass, but in the meantime it is a factor to consider.

* "Time to cockpit" is a metric of how long it takes to get into the pilot's seat once you're at the ship. Some ships have much faster access to and from the cockpit, making them great if you want to do a lot of FPS / on-foot gameplay.

* If you are absolutely certain you want to do exactly one type of gameplay, ignore this advice and get a ship tailored to that gameplay. If all you want to do is dogfighting all day, get a fighter, but maybe pay attention to its quantum range. If your dream is to be a Space Medic, get a Pisces Rescue or spring for a Cutlass Red. (but you should know you will struggle to make credits doing that right now, and while credits aren't all that necessary, they are useful!) If you are sure the only thing you want is to mine rocks, get a Prospector, but know that mining breaks every other patch or so.

* Some features described on the website may not be in the game yet, and there may be features coming soon that change the balance of which ships are best. The nature of playing a game still in alpha is that it's something of a moving target. For example, the next patch promises to bring a new requirement when buying cargo - it will be delivered to your hangar on a cargo elevator and you'll need to load it into your ship manually.[^2] Right now, the layout of your cargo grid doesn't matter, but pretty soon some ships will have a much easier time getting loaded up than others. Given the volatility of development, I'll include a "future considerations" section for each ship that discusses things that might change about a ship in the future.


# The Elephant in the Room

Yes, Cloud Imperium Games charges different prices for different starter ships, and you tend to get more capability for more money. Plenty of digital ink has been spilled discussing the ethics of their business model, and I certainly don't love it. But it's a game experience you simply can't get elsewhere, and this is currently the price to buy in. If it bothers you, I recommend limiting your choice to the "discount" ($45) ships and the "standard AAA game" ($60) ships.

# The Starter Ships, Ranked

Ok, on to the good stuff. Here are all the ships I think qualify as starters in ascending order of how good I think they are,[^3] with some weight given to the price tag of each option. I'll also try to include a discussion of why you might want each ship, regardless of its position in the ranking. Prices listed are the standard prices; discounts are occasionally available for select starter packages.

---

## 8 - 100i

{{< imgproc "images/100i.jpg" "400x" "right" "The Origin Jumpworks 100i in a hangar." />}}

### Price
* $65

### Loadout
* 2x size 3 guns
* 1x size 2 missile rack
* 2 SCU cargo grid

### Premium Features
* bed
* suit locker

### Future Considerations
* Loading cargo into this ship might be slightly bothersome, as you may need to maneuver cargo containers through the passenger door.
* Having a bed but no bathroom means that the upcoming hygeine gameplay may be tricky in this ship.

I will admit, I can't give this ship a fair shake. I just really hate the aesthetic of Origin ships. I think they're too sleek; it looks boring to me. And you're paying a "luxury tax" for this ship that it just doesn't warrant. At $65, it is less capable than everything that follows. It has a pretty good silhouette for combat, but it can't quite back it up with firepower. The interior is on the small side for a $65 ship. There's nothing it does better than any other ship on the list.

You should buy this ship if you think it looks cool, and you don't mind getting a little less "bang for your buck" in the utility department.

---

## 7 - Syulen

{{< imgproc "images/syulen_landed.jpg" "400x" "right" "The Gatac Syulen landed in a hangar." />}}

### Price
* $85

### Loadout
* 3x size 3 guns
* 3x size 4 missile racks
* 6 SCU cargo grid (but can only carry 1 SCU boxes)

### Premium Features
* bed and bathroom
* weapon rack and suit locker
* it's cool as hell

### Future Considerations
* Cargo loading is reasonable with the external cargo pods, and this ship doesn't have any features that are expected to change dramatically.

The Gatac Syulen is the newest starter, introduced at IAE 2953. I love this thing. It is beautiful, elegant, imposing. It has personality. It sings at full throttle. It has solid firepower: it's tied for second with the Nomad, and has outright the best missile loadout on this list. It is extremely maneuverable. And the interior is littered with writing in the Xi'an language, which is super cool if you're into constructed languages.

But it's a terrible starter ship.

{{< imgproc "images/syulen_flight.jpg" "400x" "left" "The Gatac Syulen in flight configuration." >}}Beautiful radial symmetry.{{</imgproc>}}

It has bad time-to-cockpit, its cargo grid is external and not flat, so it gets no vehicle storage and can't fit cargo containers larger than 1 SCU. The vertical takeoff profile is confusing to plenty of veteran pilots, let alone new ones, making takeoff and landing quite a challenge. And it has a hefty "alien tax", being a fair bit more expensive than the loadout warrants. It does boast the best missile loadout of the lot, but the Titan is cheaper and has better guns, and the Nomad is about the same price and is more practical in every way, plus comes with *4 times* the cargo capacity.

You should buy this ship if you have already been playing the game for a while or just don't care about practicality. But if you do, be prepared to be frustrated.

---

## 6 - Aurora MR

{{< imgproc "images/aurora.jpg" "400x" "right" "The RSI Aurora MR in a hangar." />}}

### Price
* $45

### Loadout
* 2x size 1 guns
* 1x size 2 missile rack
* 3 SCU cargo grid

### Premium Features
* bed

### Future Considerations
* The underslung cargo rack may be difficult to load, since containers must be slid in from the front. In practice this is currently a bit challenging.
* Having a bed but no bathroom means that the upcoming hygeine gameplay may be tricky in this ship.
* The lack of a suit locker may make it difficult to wear heavy armor while piloting this ship in the future.

The second starter added to the game. Has a bed and a small interior. Aesthetically I like this ship better than the Mustang, but the Mustang is a bit more capable in both combat and storage. There's nothing wrong with the Aurora per se, but it sacrifices a fair bit compared to the Mustang for the luxury of a bed.

You should buy this ship if you absolutely aren't going to spend more than $45 on this game and don't like the look of the Mustang or don't want to focus on ship combat at all. The bed also has some utility if you regularly have to log out in a hurry.

---

## 5 - Mustang Alpha

{{< imgproc "images/mustang.jpg" "400x" "right" "The Consolidated Outland Mustang Alpha in a hangar." />}}

### Price
* $45

### Loadout
* 2x size 1 guns
* 2x size 2 guns
* 4 SCU cargo grid

### Premium Features
* direct cockpit access

### Future Considerations
* Manually loading cargo containers into the Mustang's cargo 'box' requires some finesse and wiggling, making it a bit slower to load than other ships.
* The lack of a suit locker may make it difficult to wear heavy armor while piloting this ship in the future.

The original starter ship, the Mustang Alpha from Consolidated Outland is still a surprisingly strong contender, depending on what you want to do in the game. It has a classic "space fighter" aesthetic that is bound to appeal to some players. The very first ship designed for the game, it is the only ship in this list without a walkable interior - it *only* has direct cockpit access, so it definitely feels more like a fighter plane than something a long-haul spacefarer would want to live in. It is fast and nimble and has great sustained damage output for its price, if dogfighting is something that appeals to you. You won't see higher sustained damage potential until you get to the premium price range. ($75 or more)

You should buy this ship if you want to get into combat but you're on a budget, really value getting into and out of your ship in a hurry, or want something with an *extremely* small silhouette that can land between two trees in a densely packed forest. This is a light fighter that can carry some cargo, and it's genuinely fun to fly, but it isn't as well-rounded as the other options. This is the first ship on the list that I would genuinely consider to be a good choice.

---

## 4 - C8X Pisces Expedition

{{< imgproc "images/pisces.jpg" "400x" "right" "The Anvil Aerospace C8X Pisces Expedition in a hangar." />}}

### Price
* $60

### Loadout
* 4x size 1 guns
* 2x size 1 missile racks
* 4 SCU cargo grid

### Premium Features
* 2x jumpseats for transporting passengers

### Future Considerations
* The lack of a suit locker may make it difficult to wear heavy armor while piloting this ship in the future.

The Anvil Pisces is a nimble little ship with a classic profile. The jump seats are nice; I've been rescued by a Pisces pilot more than once! Has decent firepower for its price. The flat silhouette means you'll be harder to shoot head on. (or when retreating) A nicely balanced choice overall, and fairly popular in the Star Citizen community.

You should buy this ship if you want a ship that can hold its own in combat without specializing in it, and that has a cozy interior with room to transport a couple friends.

---

## 3 - Cutter

{{< imgproc "images/cutter.jpg" "400x" "right" "The Drake Interplanetary Cutter in a hangar." />}}

### Price
* $60

### Loadout
* 2x size 2 guns
* 2x size 2 missile racks
* 4 SCU cargo grid

### Premium Features
* bed and bathroom
* weapon rack and suit locker
* cargo hold can fit some small ground vehicles

### Future Considerations
* This ship will be particularly well-armored once ship armor is implemented, making it a solid choice for players who want to escape from combat situations.
* The bulky shape of this ship will make it easier to detect on radar when the radar system evolves.

The Drake Cutter is a direct price competitor to the Pisces. Its weapons have slightly less sustained damage but more missiles, and it has a boxier silhouette than the Pisces as well. Combined with the slightly more spacious interior and living amenities, this is a ship which is less focused on combat and more focused on being a general runabout. It doesn't fly as well in atmospheres as the Pisces, owing to its complete lack of aerodynamics. But it *does* have VTOL-capable engines, and which makes it a solid "getaway car" because it can go straight up in a hurry. Also it's pretty cool to watch the engines rotate into place.

You should buy this ship if you want a capable all-rounder of a ship and enjoy its bulky / boxy ship design.

---

## 2 - Nomad

{{< imgproc "images/nomad.jpg" "400x" "right" "The Consolidated Outland Nomad in a hangar." />}}

### Price
* $95

### Loadout
* 3x size 3 guns
* 2x size 4 missile racks
* 24 SCU cargo grid

### Premium Features
* can carry a Roc or other small ground vehicle
* tractor beam
* bed and bathroom
* weapon rack and suit locker

### Future Considerations
* The exposed external cargo grid may be a liability if it becomes possible to dislodge cargo in combat.

By far the most versatile starter, the Consolidated Outland Nomad can do it all and has a lot of premium features to match its premium price. Often called the "space pickup" because its cargo grid is on a lowerable platform on the exterior of the ship. This means the cargo isn't fully enclosed, and is not accessible from inside the ship's living area. This also means your cargo (or ground vehicle) can be damaged or dislodged if you come under attack. 

{{< imgproc "images/nomad_interior.jpg" "300x" "left" "The Nomad's angular interior design.">}}Strange, sharp angles define the interior spaces.{{</imgproc>}}

The most obvious points of comparison here are the Avenger Titan (below) and the Syulen (above). With 3 size 3 hardpoints, it matches the Syulen for firepower and has a better head-on silhouette. It sits between the Avenger and Syulen on missile loadout, and at 24 SCU of cargo it towers above any other option.

One thing to note about the Nomad is that it has a unique aesthetic. It uses hover tech on its entryway and landing gear and has a very angular, almost alien interior. (obviously less alien than the Syulen, but still) A lot of people think the piloting console looks a little "cheap" because it has oddly flat displays and "Star Trek" style virtual buttons on glass panes. I think it is a distinctive and interesting look, but your mileage may vary.

{{< imgproc "images/nomad_cockpit.jpg" "300x" "right" "The Nomad's distinctive control console." >}}A distinctive approach to console buttons.{{</imgproc>}}

It doesn't make the top of the list purely because its price tag is more than *twice* the lowest entry point. The Avenger Titan gives better overall value for the price.

You should buy this ship if money is no object and you want an *extremely* capable solo vessel. If this ship were priced down to $80 it would be in 1st place.

---

## 1 - Avenger Titan

{{< imgproc "images/avenger.jpg" "400x" "right" "The Aegis Dynamics Avenger Titan in a hangar." />}}

### Price
* $75

### Loadout
* 1x size 4 gun
* 2x size 3 guns
* 2x size 3 missile racks
* 8 SCU cargo grid

### Premium Features
* direct cockpit access
* bed

### Future Considerations
* The lack of a suit locker may make it difficult to wear heavy armor while piloting this ship in the future.
* Having a bed but no bathroom means that the upcoming hygeine gameplay may be tricky in this ship.

{{< imgproc "images/avenger_cockpit.jpg" "300x" "left" "The Avenger's quick-access cockpit configuration." >}}Easy cockpit access for the pilot on the go.{{</imgproc>}}

When you ask a lot of people what starter to get, they'll say "get the Avenger Titan, you can't go wrong with it." And it's hard to argue with them, because they're right. This ship is an all-around great starter, and if price isn't a huge concern, this is pretty much your de facto pick unless you really like the style of another ship or want to pay extra for the Nomad.

{{< imgproc "images/avenger_bay.jpg" "300x" "right" "The Avenger's cargo bay.">}}A cozy cargo bay{{</imgproc>}}

For its premium price tag, the Aegis Avenger Titan gives you the biggest guns on the list, the second-biggest missile loadout bigger missiles, and a cargo hold large enough to start to feel like a proper hauler. It is also quite nimble and small enough to land anywhere your journey takes you. It doesn't have all the amenities of other ships, but it does have the most crucial one: a bed.

{{< imgproc "images/avenger_hab.jpg" "300x" "left" "The Avenger's habitation area." >}}An even cozier habitation section.{{</imgproc>}}

You should buy this ship if you want a solid foundation for trying a little bit of everything. It has the best balance between price and capabilities on this list, though the Nomad is a *close* second place.

&nbsp; 

&nbsp; 

---

# I'm Tired of Flying a Starter Ship, What Should I Do Now?

You have 2 main routes in this case: get a specialized ship and do some specialized gameplay, or else upgrade to a medium-sized "daily driver" soloable ship, like the Freelancer, C1 Spirit, or Cutlass Black. If you like the feeling and challenge of flying larger/more cumbersome ships, you can consider something like the Corsair, Constellation, MSR, or the C2 Hercules. Whether you earn credits in-game to purchase these ships[^4] or buy them with your real money on the [pledge store](https://robertsspaceindustries.com/pledge) is a personal decision; I'm not a huge fan of CIG's business model, but if you have more expendable income than free time and want to get right to the ships you think sound fun, I feel like that's a perfectly reasonable decision.

[^1]: "Box delivery" missions are often bugged, so may or may not actually be a good activity to do.
[^2]: The developers' intent is to allow you to pay to have NPCs load your ship for you, but there's no telling whether that will be implemented when this feature initially arrives. That's perpetual alpha, baby!
[^3]: Look for updated versions of this guide as new starters are added to the game as well.
[^4]: Note that, while the game is still in Alpha, ships purchased in-game will be lost every time the devs do a database wipe. This happens about once a year, but there are no guarantees.
